==> boinc_7.6.31+dfsg.orig.tar.gz: boinc-client_release-7.6-7.6.31/html/user/edit_email_form.php <==
<?php
// This file is part of BOINC.
// http://boinc.berkeley.edu
// Copyright (C) 2008 University of California
//
// BOINC is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// BOINC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

require_once("../inc/util.inc");
require_once("../inc/email.inc");

check_get_args(array());

redirect_to_secure_url("edit_email_form.php");
$user = get_logged_in_user();

page_head(tra("Change email address"));

$email_text = "";
if (is_valid_email_addr($user->email_addr)) {
    $email_text = $user->email_addr;
}

echo "<form method=post action=".secure_url_base()."/edit_email_action.php>\n";
start_table();
row1(tra("Change the email address of your account"));
row2(tra("New email address").
    "<br><p class=\"text-muted\">".tra("Must be a valid address of the form 'name@domain'")."</p>",
    "<input name=email_addr size=50 type=text value='$email_text'>"
);

// we need the password here not for verification,
// but because we store it salted with email address,
// which is about to change.

row2(
    tra("Password").
    "<br><a href=".secure_url_base()."/edit_passwd_form.php><p class=\"text-muted\">".tra("No password?")."</p></a>",
    "<input type=password name=passwd>"
);
row2("", "<input class=\"btn btn-default\" type=submit value='".tra("Change email address")."'>");
end_table();
echo "</form>\n";
page_tail();

?>

==> boinc_7.9.3+dfsg.orig.tar.gz: boinc-client_release-7.10-7.9.3/html/user/edit_email_form.php <==
<?php
// This file is part of BOINC.
// http://boinc.berkeley.edu
// Copyright (C) 2008 University of California
//
// BOINC is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// BOINC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

require_once("../inc/util.inc");
require_once("../inc/email.inc");

check_get_args(array());

redirect_to_secure_url("edit_email_form.php");
$user = get_logged_in_user();

page_head(tra("Change email address"));

$email_text = "";
if (is_valid_email_addr($user->email_addr)) {
    $email_text = $user->email_addr;
}

form_start(secure_url_base()."/edit_email_action.php", "post");
form_input_text(
    tra("New email address").
    "<br><p class=\"text-muted\">".tra("Must be a valid address of the form 'name@domain'")."</p>",
    "email_addr", $email_text
);

// we need the password here not for verification,
// but because we store it salted with email address,
// which is about to change.

form_input_text(tra("Password"), "passwd", "", "password");
form_submit(tra("Change email address"));
form_end();
page_tail();

?>
